Enum pancake_engine_ssi::opers::fc::fc_compaction::CompactionResult
source · pub(super) enum CompactionResult {
NoChange,
Empty,
Some(CommittedUnit),
}Variants
NoChange
Flushing+compaction would not have changed the given slice of Units; hence was not executed.
Empty
Flushing+compaction was executed, and resulted in an empty Unit.
Some(CommittedUnit)
Flushing+compaction was executed, and resulted in one Unit containing 1+ non-empty SSTables.